@@ -21,7 +21,6 @@
 *                                                                             *
 *                                                                             *
 *                                                                             *
-*   For further information contact me at johnvarouhakis@gmail.com            *
 ******************************************************************************/
 
 #include "config.h"
@@ -46,7 +45,7 @@
 *
 *   \returns Zero always
 */
-static int JackCapture(jack_nframes_t nframes,void *jdata_t) {
+static int rmdJackCapture(jack_nframes_t nframes,void *jdata_t) {
     int i=0;
     JackData *jdata=(JackData *)jdata_t;
 
@@ -67,7 +66,7 @@ static int JackCapture(jack_nframes_t nframes,void *jdata_t) {
 /*FIXME */
 //This is not safe.
 //cond_var signaling must move away from signal handlers
-//alltogether (JackCapture, SetExpired, SetPaused).
+//alltogether (rmdJackCapture, SetExpired, SetPaused).
 //Better would be a set of pipes for each of these.
 //The callback should write on the pipe and the main thread
 //should perform a select over the fd's, signaling afterwards the
@@ -87,7 +86,7 @@ static int JackCapture(jack_nframes_t nframes,void *jdata_t) {
 *
 *   \returns 0 on Success, 1 on failure
 */
-static int SetupPorts(JackData *jdata) {
+static int rmdSetupPorts(JackData *jdata) {
     int i=0;
     jdata->ports=malloc(sizeof(jack_port_t *)*
                                jdata->nports);
@@ -98,9 +97,9 @@ static int SetupPorts(JackData *jdata) {
 
     for(i=0;i<jdata->nports;i++){
         char name[64];//recordMyDesktop:input_n<64 is enough for full name
-        char num[8];
+        char num[11];
         strcpy(name,"input_");
-        snprintf( num, 8, "%d", i+1 );
+        snprintf( num, 11, "%d", i+1 );
         strcat(name,num);
         if((jdata->ports[i]=jack_port_register(jdata->client,
                                                  name,
@@ -126,7 +125,7 @@ static int SetupPorts(JackData *jdata) {
 //the program should stop recording,
 //encode the result(if not on the fly)
 //an exit cleanly.
-static void JackShutdown(void *jdata_t) {
+static void rmdJackShutdown(void *jdata_t) {
     JackData *jdata = (JackData *)jdata_t;
 
     jdata->pdata->running = FALSE;
@@ -134,7 +133,7 @@ static void JackShutdown(void *jdata_t) {
     fprintf (stderr, "JACK shutdown\n");
 }
 
-int StartJackClient(JackData *jdata){
+int rmdStartJackClient(JackData *jdata){
     float ring_buffer_size=0.0;
     int pid;
     char pidbuf[8];
@@ -150,7 +149,13 @@ int StartJackClient(JackData *jdata){
     snprintf( pidbuf, 8, "%d", pid );
     strcat(rmd_client_name,pidbuf);
 
-    if ((jdata->client=(*jack_client_new)(rmd_client_name))==0){
+    jack_options_t options = JackUseExactName;
+
+    if (getenv ("JACK_START_SERVER") == NULL) {
+        options |= JackNoStartServer;
+    }
+
+    if ((jdata->client=(*jack_client_open)(rmd_client_name, options, NULL))==0){
         fprintf(stderr,"Could not create new client!\n"
                        "Make sure that Jack server is running!\n");
         return 15;
@@ -176,14 +181,14 @@ int StartJackClient(JackData *jdata){
                       jdata->nports);
     jdata->sound_buffer=
         (*jack_ringbuffer_create)((int)(ring_buffer_size+0.5));//round up
-    jack_set_process_callback(jdata->client,JackCapture,jdata);
-    jack_on_shutdown(jdata->client,JackShutdown,jdata);
+    jack_set_process_callback(jdata->client,rmdJackCapture,jdata);
+    jack_on_shutdown(jdata->client,rmdJackShutdown,jdata);
 
     if (jack_activate(jdata->client)) {
         fprintf(stderr,"cannot activate client!\n");
         return 16;
     }
-    if(SetupPorts(jdata)){
+    if(rmdSetupPorts(jdata)){
         jack_client_close(jdata->client);
         return 17;
     }
@@ -191,7 +196,7 @@ int StartJackClient(JackData *jdata){
     return 0;
 }
 
-int StopJackClient(JackData *jdata){
+int rmdStopJackClient(JackData *jdata){
     int ret=0;
 
     (*jack_ringbuffer_free)(jdata->sound_buffer);
