@@ -21,7 +21,6 @@
 *                                                                             *
 *                                                                             *
 *                                                                             *
-*   For further information contact me at johnvarouhakis@gmail.com            *
 ******************************************************************************/
 
 #include "config.h"
@@ -37,6 +36,7 @@
 #include <pthread.h>
 
 #include <string.h>
+#include <stdlib.h>
 
 
 int rmdRescue(const char *path){
@@ -48,11 +48,11 @@ int rmdRescue(const char *path){
     unsigned short  width,
                     height;
 
-    ProgData pdata;
-    EncData enc_data;
-    CacheData cache_data;
+    ProgData pdata={0};
+    EncData enc_data={0};
+    CacheData cache_data={0};
 
-    SetupDefaultArgs(&pdata.args);
+    rmdSetupDefaultArgs(&pdata.args);
 
     pdata.enc_data=&enc_data;
     pdata.cache_data=&cache_data;
@@ -75,7 +75,7 @@ int rmdRescue(const char *path){
     strcat(cache_data.specsfile,"specs.txt");
     
 
-    if(ReadSpecsFile(&pdata))
+    if(rmdReadSpecsFile(&pdata))
         return 1;
 
         
@@ -124,14 +124,14 @@ int rmdRescue(const char *path){
     pdata.running = TRUE;
     pdata.aborted = FALSE;
 
-    RegisterCallbacks(&pdata);
+    rmdRegisterCallbacks(&pdata);
     fprintf(stderr,"Restoring %s!!!\n",path);
     
-    EncodeCache(&pdata);
+    rmdEncodeCache(&pdata);
 
     fprintf(stderr,"Done!!!\n");
     fprintf(stderr,"Goodbye!\n");
-    CleanUp();
+    rmdCleanUp();
     
     return 0;
 }
